@@ -15,12 +15,14 @@
 * limitations under the License.
 */
 
-ALTER TABLE "public"."t_external_link"
-    ALTER COLUMN "link_url" TYPE text collate "pg_catalog"."default";
+UPDATE t_flink_app
+SET flink_cluster_id = t_flink_cluster.id
+    FROM t_flink_cluster
+WHERE t_flink_app.cluster_id = t_flink_cluster.cluster_id
+  AND t_flink_app.execution_mode = 5;
 
-ALTER TABLE "public"."t_flink_project"
-    ALTER COLUMN "branches" TYPE varchar(255) collate "pg_catalog"."default";
-
-ALTER TABLE "public"."t_flink_project"
-    rename column "branches" to "refs";
+UPDATE t_flink_app
+SET cluster_id = app_id
+WHERE execution_mode IN (2,3,4);
 
+ALTER TABLE t_flink_app DROP COLUMN app_id;
